@@ -96,7 +96,7 @@ tvm_preferences_dialog_init (TvmPreferencesDialog *dialog)
   channel = xfconf_channel_get ("thunar-volman");
 
   /* configure the dialog properties */
-  gtk_window_set_icon_name (GTK_WINDOW (dialog), "drive-removable-media");
+  gtk_window_set_icon_name (GTK_WINDOW (dialog), "org.xfce.volman");
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
   gtk_window_set_title (GTK_WINDOW (dialog), _("Removable Drives and Media"));
   xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dialog), 
@@ -105,16 +105,28 @@ tvm_preferences_dialog_init (TvmPreferencesDialog *dialog)
 
   g_signal_connect (dialog, "response", G_CALLBACK (tvm_preferences_dialog_response), NULL);
 
+#if LIBXFCE4UI_CHECK_VERSION (4, 15, 1)
+  xfce_titled_dialog_create_action_area (XFCE_TITLED_DIALOG (dialog));
+#endif
+
   /* add "Help" button */
   button = gtk_button_new_from_icon_name ("help-browser", GTK_ICON_SIZE_BUTTON);
   gtk_button_set_label (GTK_BUTTON (button), _("Help"));
+#if LIBXFCE4UI_CHECK_VERSION (4, 15, 1)
+  xfce_titled_dialog_add_action_widget (XFCE_TITLED_DIALOG (dialog), button, GTK_RESPONSE_HELP);
+#else
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_HELP);
+#endif
   gtk_widget_show (button);
 
   /* add "Close" button */
   button = gtk_button_new_from_icon_name ("window-close", GTK_ICON_SIZE_BUTTON);
   gtk_button_set_label (GTK_BUTTON (button), _("Close"));
+#if LIBXFCE4UI_CHECK_VERSION (4, 15, 1)
+  xfce_titled_dialog_add_action_widget (XFCE_TITLED_DIALOG (dialog), button, GTK_RESPONSE_CLOSE);
+#else
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_CLOSE);
+#endif
   gtk_widget_show (button);
 
   notebook = gtk_notebook_new ();
@@ -149,7 +161,7 @@ tvm_preferences_dialog_init (TvmPreferencesDialog *dialog)
   gtk_container_add (GTK_CONTAINER (frame), grid);
   gtk_widget_show (grid);
 
-  image = gtk_image_new_from_icon_name ("drive-removable-media", GTK_ICON_SIZE_DIALOG);
+  image = gtk_image_new_from_icon_name ("media-removable", GTK_ICON_SIZE_DIALOG);
   gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (image, GTK_ALIGN_START);
   gtk_grid_attach (GTK_GRID (grid), image, 0, 0, 1, 3);
@@ -206,7 +218,7 @@ tvm_preferences_dialog_init (TvmPreferencesDialog *dialog)
   gtk_container_add (GTK_CONTAINER (frame), grid);
   gtk_widget_show (grid);
 
-  image = gtk_image_new_from_icon_name ("tvm-burn-cd", GTK_ICON_SIZE_DIALOG);
+  image = gtk_image_new_from_icon_name ("media-optical", GTK_ICON_SIZE_DIALOG);
   gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (image, GTK_ALIGN_START);
   gtk_grid_attach (GTK_GRID (grid), image, 0, 0, 1, 3);
@@ -415,96 +427,6 @@ tvm_preferences_dialog_init (TvmPreferencesDialog *dialog)
   gtk_grid_attach (GTK_GRID (grid), entry, 1, 1, 1, 1);
   gtk_widget_show (entry);
 
-  /*
-     PDAs
-   */
-  label = gtk_label_new (_("PDAs"));
-  vbox = g_object_new (GTK_TYPE_BOX, "orientation", GTK_ORIENTATION_VERTICAL, "border-width", 12, "spacing", 18, NULL);
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
-  gtk_widget_show (label);
-  gtk_widget_show (vbox);
-
-  /* FIXME make the vbox sensitive again as soon as there is PDA support */
-  gtk_widget_set_sensitive (vbox, FALSE);
-
-  frame = g_object_new (GTK_TYPE_FRAME, "border-width", 0, "shadow-type", 
-                        GTK_SHADOW_NONE, NULL);
-  gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, TRUE, 0);
-  gtk_widget_show (frame);
-
-  label = gtk_label_new (_("Palm™"));
-  gtk_label_set_attributes (GTK_LABEL (label), tvm_pango_attr_list_bold ());
-  gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-  gtk_widget_show (label);
-
-  grid = gtk_grid_new ();
-  gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
-  gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
-  gtk_widget_set_margin_top (GTK_WIDGET (grid), 6);
-  gtk_widget_set_margin_start (GTK_WIDGET (grid), 12);
-  gtk_container_add (GTK_CONTAINER (frame), grid);
-  gtk_widget_show (grid);
-
-  image = gtk_image_new_from_icon_name ("pda", GTK_ICON_SIZE_DIALOG);
-  gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
-  gtk_widget_set_valign (image, GTK_ALIGN_START);
-  gtk_grid_attach (GTK_GRID (grid), image, 0, 0, 1, 3);
-  gtk_widget_show (image);
-
-  button = gtk_check_button_new_with_mnemonic (_("Sync _Palm™ devices "
-                                                 "when connected"));
-  xfconf_g_property_bind (channel, "/autopalm/enabled", G_TYPE_BOOLEAN, 
-                          button, "active");
-  gtk_grid_attach (GTK_GRID (grid), button, 1, 0, 1, 1);
-  gtk_widget_show (button);
-
-  entry = tvm_command_entry_new_with_label (_("_Command:"));
-  xfconf_g_property_bind (channel, "/autopalm/enabled", G_TYPE_BOOLEAN, 
-                          entry, "sensitive");
-  xfconf_g_property_bind (channel, "/autopalm/command", G_TYPE_STRING, 
-                          entry, "command");
-  gtk_grid_attach (GTK_GRID (grid), entry, 1, 1, 1, 1);
-  gtk_widget_show (entry);
-
-  frame = g_object_new (GTK_TYPE_FRAME, "border-width", 0, "shadow-type", 
-                        GTK_SHADOW_NONE, NULL);
-  gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, TRUE, 0);
-  gtk_widget_show (frame);
-
-  label = gtk_label_new (_("Pocket PCs"));
-  gtk_label_set_attributes (GTK_LABEL (label), tvm_pango_attr_list_bold ());
-  gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-  gtk_widget_show (label);
-
-  grid = gtk_grid_new ();
-  gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
-  gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
-  gtk_widget_set_margin_top (GTK_WIDGET (grid), 6);
-  gtk_widget_set_margin_start (GTK_WIDGET (grid), 12);
-  gtk_container_add (GTK_CONTAINER (frame), grid);
-  gtk_widget_show (grid);
-
-  image = gtk_image_new_from_icon_name ("tvm-dev-pocketpc", GTK_ICON_SIZE_DIALOG);
-  gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
-  gtk_widget_set_valign (image, GTK_ALIGN_START);
-  gtk_grid_attach (GTK_GRID (grid), image, 0, 0, 1, 3);
-  gtk_widget_show (image);
-
-  button = gtk_check_button_new_with_mnemonic (_("Sync Pocket P_C devices "
-                                                 "when connected"));
-  xfconf_g_property_bind (channel, "/autopocketpc/enabled", G_TYPE_BOOLEAN, 
-                          button, "active");
-  gtk_grid_attach (GTK_GRID (grid), button, 1, 0, 1, 1);
-  gtk_widget_show (button);
-
-  entry = tvm_command_entry_new_with_label (_("C_ommand:"));
-  xfconf_g_property_bind (channel, "/autopocketpc/enabled", G_TYPE_BOOLEAN, 
-                          entry, "sensitive");
-  xfconf_g_property_bind (channel, "/autopocketpc/command", G_TYPE_STRING, 
-                          entry, "command");
-  gtk_grid_attach (GTK_GRID (grid), entry, 1, 1, 1, 1);
-  gtk_widget_show (entry);
-
   /*
      Printers
    */
@@ -690,6 +612,7 @@ tvm_preferences_dialog_response (GtkWidget *dialog,
 
   if (response_id != GTK_RESPONSE_HELP)
     {
+      gtk_widget_destroy (dialog);
       gtk_main_quit ();
       return;
     }
